@@ -1,4 +1,4 @@
-from .geometry import Geometry, Object, Mesh, MeshPhongMaterial, OrthographicCamera, PointsMaterial, Points
+from .geometry import Geometry, Object, Mesh, MeshPhongMaterial, OrthographicCamera, PerspectiveCamera, PointsMaterial, Points
 from .path import Path
 
 
@@ -9,7 +9,7 @@ class SetObject:
             if material is not None:
                 raise(ValueError("Please supply either an Object OR a Geometry and a Material"))
             self.object = geometry_or_object
-        elif isinstance(geometry_or_object, OrthographicCamera):
+        elif isinstance(geometry_or_object, (OrthographicCamera, PerspectiveCamera)):
             self.object = geometry_or_object
         else:
             if material is None:
