@@ -1,7 +1,7 @@
 var THREE = require('three');
 var msgpack = require('msgpack-lite');
 var dat = require('dat.gui').default; // TODO: why is .default needed?
-import {BufferGeometryUtils} from 'three/examples/jsm/utils/BufferGeometryUtils.js';
+import {mergeBufferGeometries} from 'three/examples/jsm/utils/BufferGeometryUtils.js';
 import {OBJLoader2, MtlObjBridge} from 'wwobjloader2'
 import {ColladaLoader} from 'three/examples/jsm/loaders/ColladaLoader.js';
 import {MTLLoader} from 'three/examples/jsm/loaders/MTLLoader.js';
@@ -36,7 +36,7 @@ function merge_geometries(object, preserve_materials = false) {
             result.material = materials[0];
         }
     } else if (geometries.length > 1) {
-        result = BufferGeometryUtils.mergeBufferGeometries(geometries, true);
+        result = mergeBufferGeometries(geometries, true);
         if (preserve_materials) {
             result.material = materials;
         }
@@ -628,7 +628,12 @@ class Animator {
         this.progress = 0;
         for (let animation of animations) {
             let target = this.viewer.scene_tree.find(animation.path).object;
-            let clip = Object.values(this.loader.parseAnimations([animation.clip]))[0];
+            let clip = THREE.AnimationClip.parse(animation.clip);
+            // Ensure the clip has a proper UUID (by default it's undefined).
+            // The animation mixer uses that UUID internally, and not setting it
+            // can result in animations accidentally overwriting each other's
+            // properties.
+            clip.uuid = THREE.MathUtils.generateUUID();
             let action = this.mixer.clipAction(clip, target);
             action.clampWhenFinished = options.clampWhenFinished;
             action.setLoop(options.loopMode, options.repetitions);
@@ -720,6 +725,7 @@ class Viewer {
         } else {
             this.renderer = renderer;
         }
+        this.renderer.setPixelRatio(window.devicePixelRatio);
 
         this.scene = create_default_scene();
         this.gui_controllers = {};
@@ -992,14 +998,20 @@ class Viewer {
         } else {
             handler[name] = eval(callback);
             this.gui_controllers[name] = this.gui.add(handler, name);
+            // The default layout for dat.GUI buttons is broken, with the button name artificially truncated at the same width that slider names are truncated.  We fix that here.
+            this.gui_controllers[name].domElement.parentElement.querySelector('.property-name').style.width="100%";
         }
     }
 
-    set_control_value(name, value) {
+    set_control_value(name, value, invoke_callback=true) {
         if (name in this.gui_controllers && this.gui_controllers[name] 
             instanceof dat.controllers.NumberController) {
-            this.gui_controllers[name].setValue(value);
-            this.gui_controllers[name].updateDisplay();
+            if (invoke_callback) {
+              this.gui_controllers[name].setValue(value);              
+            } else {
+              this.gui_controllers[name].object[name] = value;
+              this.gui_controllers[name].updateDisplay();
+            }
         }
     }
 
@@ -1031,7 +1043,7 @@ class Viewer {
         } else if (cmd.type == "set_control") {
             this.set_control(cmd.name, cmd.callback, cmd.value, cmd.min, cmd.max, cmd.step);
         } else if (cmd.type == "set_control_value") {
-            this.set_control_value(cmd.name, cmd.value);
+            this.set_control_value(cmd.name, cmd.value, cmd.invoke_callback);
         } else if (cmd.type == "delete_control") {
             this.delete_control(cmd.name);
         } else if (cmd.type == "capture_image") {
